#!/bin/sh

set -x
glib-gettextize --copy --force

libtoolize --automake --copy --force
intltoolize --automake --copy --force

# Scan configure.ac and copy the necessary macros into aclocal.m4.
aclocal

autoconf --force
#autoheader --force
automake --add-missing --copy --force-missing --foreign

# Create needed information files (if it was not done earlier)
touch NEWS README AUTHORS ChangeLog

